﻿/*
**  Imager Form Application
**
** copyright(c) 2017 株式会社トラスト・ソフトウェア・システム,All Rights Reserved.
**/

using System;
using System.Text;
using System.Text.RegularExpressions;
using System.Windows.Forms;
using Microsoft.VisualBasic;
using PDFTools.PdfImagerLP;

namespace ImagerApp
{
	public partial class Imager : Form
	{
		private PdfImager p2i;
		private int pdfVersion;
		private int pageCount;
		private ThreadDlg threadDlg;
		private ColorprofileDlg cprofDlg;
		private WatermarkImgDlg wtmImgDlg;
		private WatermarkStrDlg wtmStrDlg;

		//生成
		public Imager()
		{
			InitializeComponent();
			p2i = new PdfImager();
			pageCount = -1;
		}

		/*
		 * 初期化
		 */
		private void initBtn_Click(object sender, EventArgs e)
		{
			switch (p2i.Initialize("0-W0H6-7H5GKW7E336R"))  //適切なライセンスキーに替えてください。
			{
				case err.MLP_NO_ERROR: break;
				case err.MLP_ALREADY_INITIALIZED: MessageBox.Show("既に初期化されています"); return;
				case err.MLP_NOT_INITIALIZED:     MessageBox.Show("初期化できませんでした"); return;
				case err.MLP_LICENSE_ERROR:
					string lic = Interaction.InputBox("ライセンスキーを入力してください。", "ライセンスキー", "", 0, 0);
					if(p2i.Initialize(lic) == err.MLP_NO_ERROR) break;
					MessageBox.Show("ライセンスが不正です");
					return;
				default: MessageBox.Show("初期化エラー"); return;
			}

			//ライセンス詳細
			StringBuilder licStr = new StringBuilder(70);
			p2i.GetLicenseInfoStr(licStr);
			licenseStrTxt.Text = licStr.ToString();

			//初期化ファイル
			if (initFileChk.Checked)
			{
				if (p2i.LoadInitFile(initFileNameTxt.Text) != 0)
					MessageBox.Show("初期化ファイルを読めません。");
			}

			//スレッド
			threadDlg = new ThreadDlg();

			//カラープロファイル
			cprofDlg = new ColorprofileDlg();

			//Buttons...
			initBtn.Enabled = false;
			uninitBtn.Enabled = openDocBtn.Enabled = true;
			initFileChk.Enabled = initFileNameTxt.Enabled = initFileRefBtn.Enabled = false;
			coloprofileBtn.Enabled = true;
#if true
			pngRb.Checked = true;
			pageNumRb.Checked = true;
			outFileNameTxt.Text = "out.png";
#elif false
			jpegRb.Checked = true;
			pageNumRb.Checked = true;
			outFileNameTxt.Text = "out.jpg";
#elif false
			tiffRb.Checked = true;
			pageRangeRb.Checked = true;
			outFileNameTxt.Text = "out.tiff";
#endif
			compressNoneRb.Checked = true;
			splitPageChk.Enabled = eachPageChk.Enabled = true;
			threadDetailBtn.Enabled = true;
			antialiasFillPathChk.Enabled = antialiasTextChk.Enabled = true;
		}

		/*
		 * MLP終了
		 */
		private void uninitBtn_Click(object sender, EventArgs e)
		{
			p2i.CloseDoc();
			p2i.Uninitialize();
			threadDlg = null;
			cprofDlg = null;

			//Buttons...
			licenseStrTxt.Text = "";
			initBtn.Enabled = true;
			uninitBtn.Enabled = openDocBtn.Enabled = closeDocBtn.Enabled = false;
			initFileChk.Checked = false;
			initFileChk.Enabled = true;
			coloprofileBtn.Enabled = false;

			splitPageChk.Enabled = eachPageChk.Enabled = false;
			threadDetailBtn.Enabled = false;
			antialiasFillPathChk.Enabled = antialiasTextChk.Enabled = false;
		}

		/*
		 * PDFを開く
		 */
		private void openDocBtn_Click(object sender, EventArgs e)
		{
			//チェック
			if (pdfFileNameTxt.Text.Length == 0)
			{
				MessageBox.Show("PDFファイルを指定してください");
				return;
			}

			//Open
			switch(p2i.OpenDoc(pdfFileNameTxt.Text, "", ""))
			{
				case err.MLP_NO_ERROR: break;
				case err.MLP_NOT_INITIALIZED: MessageBox.Show("初期化されていません"); return;
				case err.MLP_ALREADY_OPENED:  MessageBox.Show("既にオープンしています"); return;
				case err.MLP_FILE_OPEN_ERROR: MessageBox.Show("オープンできません"); return;
				case err.MLP_FILE_IS_NOT_PDF: MessageBox.Show("PDFではありません"); return;
				case err.MLP_FILE_NOT_DECRYPTED:
					PasswordDlg dlg = new PasswordDlg();
					if (dlg.ShowDialog() != DialogResult.OK)
					{
						MessageBox.Show("復号できません");
						return;
					}
					if (p2i.OpenDoc(pdfFileNameTxt.Text, dlg.ownerPswd, dlg.userPswd) != 0)
					{
						MessageBox.Show("復号できません");
						return;
					}
					switch (dlg.openMode)
					{
						case 0: modeLbl.Text = "(表示および印刷)"; break;
						case 1: modeLbl.Text = "(表示モード)"; break;
						case 2: modeLbl.Text = "(印刷モード)"; break;
					}
					int restrict;
					p2i.GetDocumentInfo(DocumentOpt.PRINT_RESTRICTION, out restrict);
					switch (restrict)
					{
						case 0: passwordEncLbl.Text = "このPDFファイルは、パスワードで暗号化されています。\r\n(印刷制限はありません。)"; break;
						case 1: passwordEncLbl.Text = "このPDFファイルは、パスワードで暗号化されています。\r\n(低解像度印刷が指定されています。)"; break;
						case 2: passwordEncLbl.Text = "このPDFファイルは、パスワードで暗号化されています。\r\n(印刷は許可されていません。)"; break;
					}
					passwordEncLbl.Enabled = true;
					break;
			}

			//ボタン...
			//この状態によっていくつかのフィールドが更新される
			uninitBtn.Enabled = openDocBtn.Enabled = false;
			closeDocBtn.Enabled = true;

			//文書タイトル
			string title;
			p2i.GetDocumentInfo(DocumentOpt.DOCUMENT_TITLE, out title);
			if(title == "") docTitleLbl.Text = "タイトル:（ありません）" + title;
			else docTitleLbl.Text = "タイトル: " + title;
			docTitleLbl.Enabled = true;

			//文書のバージョン
			p2i.GetDocumentInfo(DocumentOpt.PDF_VERSION, out pdfVersion);
			pdfVersionLbl.Text = "PDF" + pdfVersion / 10.0;
			pdfVersionLbl.Enabled = true;

			//ページ境界
			if (mediaBoxRb.Checked) p2i.SetPicture(PictureOpt.PICTURE_USE_MEDIABOX);
			else if (cropBoxRb.Checked) p2i.SetPicture(PictureOpt.PICTURE_USE_CROPBOX);
			else if (bleedBoxRb.Checked) p2i.SetPicture(PictureOpt.PICTURE_USE_BLEEDBOX);
			else if (trimBoxRb.Checked) p2i.SetPicture(PictureOpt.PICTURE_USE_TRIMBOX);
			else if (artBoxRb.Checked) p2i.SetPicture(PictureOpt.PICTURE_USE_ARTBOX);
			else
			{
				mediaBoxRb.Checked = true;
				p2i.SetPicture(PictureOpt.PICTURE_USE_MEDIABOX);
			}

			//総ページ数
			pageCount = p2i.PageCount();
			if (pageCount < 1)
			{
				MessageBox.Show("ページがありません");
				pageListTxt.Text = "";
				return;
			}
			pageCountLbl.Text = "ページ数: " + pageCount;
			pageCountLbl.Enabled = true;
			if (pngRb.Checked || jpegRb.Checked)
			{
				pageListTxt.Text = "1";
				pageRangeRb.Enabled = allPagesRb.Enabled = false;
				pageNumRb.Enabled = true;
			}
			else
			{
				if (pageRangeRb.Checked) pageListTxt.Text = "1-" + pageCount;
				else pageListTxt.Text = "1";
				pageRangeRb.Enabled = pageNumRb.Enabled = allPagesRb.Enabled = false;
			}

			//OCG
			int nOCG = p2i.GetOcgCount();
			if (0 < nOCG)
			{
				layerDetailBtn.Enabled = ocgCountLbl.Enabled = true;
				ocgCountLbl.Text = "(OCG数: " + nOCG + ")";
			}

			//透かし
			wtmImgDlg = new WatermarkImgDlg();
			wtmStrDlg = new WatermarkStrDlg();

			//ボタン...
			pngRb.Enabled = jpegRb.Enabled = tiffRb.Enabled = true;
			outFileNameTxt.Enabled = outFileRefBtn.Enabled = true;
			mediaBoxRb.Enabled = cropBoxRb.Enabled = bleedBoxRb.Enabled = trimBoxRb.Enabled = artBoxRb.Enabled = true;
			pageListTxt.Enabled = pageToPictBtn.Enabled = true;
			fontInfoBtn.Enabled = true;
			wtmImgChk.Enabled = wtmStrChk.Enabled = true;
			logSizeXTxt.Enabled = logSizeYTxt.Enabled = true;
			unitPercentRb.Enabled = unitInchRb.Enabled = unitMmRb.Enabled = true;
		}

		// 入力ファイル参照
		private void fileRefBtn_Click(object sender, EventArgs e)
		{
			OpenFileDialog dlg = new OpenFileDialog();

			dlg.Filter = "PDFファイル|*.pdf|すべて|*.*";
			dlg.CheckFileExists = true;
			if (dlg.ShowDialog() == DialogResult.OK) pdfFileNameTxt.Text = dlg.FileName;
		}

		/*
		 * PDFを閉じる
		 */
		private void closeDocBtn_Click(object sender, EventArgs e)
		{
			p2i.CloseDoc();
			pageCount = -1;

			//透かし
			wtmImgDlg = null;
			wtmStrDlg = null;

			//ボタン...
			pageToPictBtn.Enabled = false;
			pageListTxt.Text = "";
			pageListTxt.Enabled = false;
			pngRb.Enabled = jpegRb.Enabled = tiffRb.Enabled = false;
			outFileNameTxt.Enabled = outFileRefBtn.Enabled = false;
			pageRangeRb.Enabled = pageNumRb.Enabled = allPagesRb.Enabled = false;
			fontInfoBtn.Enabled = ocgCountLbl.Enabled = layerDetailBtn.Enabled = true;
			wtmImgChk.Checked = wtmStrChk.Checked = wtmImgChk.Enabled = wtmStrChk.Enabled = false;
			mediaBoxRb.Enabled = cropBoxRb.Enabled = bleedBoxRb.Enabled = trimBoxRb.Enabled = artBoxRb.Enabled = false;
			logSizeXTxt.Enabled = logSizeYTxt.Enabled = false;
			unitPercentRb.Enabled = unitInchRb.Enabled = unitMmRb.Enabled = false;

			passwordEncLbl.Text = "(開く際にパスワードが必要な場合があります。)";
			pageCountLbl.Text = "ページ数";
			docTitleLbl.Text = "タイトル";
			pdfVersionLbl.Text = "PDFx.x";
			pageRotateLbl.Text = "ページ回転";
			pageSizeLbl.Text = "ページサイズ";
			pageBoundsLbl.Text = "ページ境界";
			pageCountLbl.Enabled = docTitleLbl.Enabled = pdfVersionLbl.Enabled = passwordEncLbl.Enabled = false;
			pageRotateLbl.Enabled = pageSizeLbl.Enabled = pageBoundsLbl.Enabled = false;
			canvasXSizeTxt.Text = canvasYSizeTxt.Text = "";

			uninitBtn.Enabled = openDocBtn.Enabled = true;
			closeDocBtn.Enabled = false;
		}

		/*
		 * 画像作成
		 */
		private void pageToPictBtn_Click(object sender, EventArgs e)
		{
			//解像度
			int dpi = GetLeadingInteger(dpiTxt.Text);
			if (dpi < 50) dpi = 50;
			else if (dpi > 10000) dpi = 10000;
			p2i.SetPictureResolution(dpi);

			//品質
			int quality = GetLeadingInteger(qualityTxt.Text);
			if (quality < 10) quality = 10;
			else if (quality > 90) quality = 90;
			p2i.SetPictureQuality(quality);

			//色指定
			if (compressNoneRb.Checked) p2i.SetTiffCompress(TiffCompressMode.MLP_TIFF_COMPRESS_NONE);
			else if (compressJpgRb.Checked) p2i.SetTiffCompress(TiffCompressMode.MLP_TIFF_COMPRESS_JPEG);
			else if (compressDeflateRb.Checked) p2i.SetTiffCompress(TiffCompressMode.MLP_TIFF_COMPRESS_DEFLATE);
			else if (compressLzwRb.Checked) p2i.SetTiffCompress(TiffCompressMode.MLP_TIFF_COMPRESS_LZW);

			//カラープロファイル
			switch (cprofDlg.conv)
			{
				case 1:     //最も早い変換
					p2i.SetColorConvertForImage(1, 1);
					break;
				case 2:     //通常の変換
					p2i.SetColorConvertForImage(1, 2);
					break;
				case 3:     //カラープロファイルによる変換
					p2i.SetRGBProfile(cprofDlg.rgbProfile);
					p2i.SetCMYKProfile(cprofDlg.cmykProfile);
					p2i.SetColorConvertForImage(1, 3);
					break;
				default:
					break;
			}

			//アンチエイリアス
			p2i.SetPicture(PictureOpt.FILL_PATH_AA, !antialiasFillPathChk.Checked);
			p2i.SetPicture(PictureOpt.TEXT_ANTIALIAS, !antialiasTextChk.Checked);

			//最小線幅
			if (minLineWidthTxt.Text != "")
			{
				float minWidth = float.Parse(minLineWidthTxt.Text);
				if (0 < minWidth) p2i.SetPicture(PictureOpt.STROKEPATH_MINIMUM_LINE_WIDTH, minWidth);
			}

			//キャンバスサイズ
			int cvsx, cvsy;
			try
			{
				cvsx = int.Parse(canvasXSizeTxt.Text);
				if (cvsx < 10) cvsx = 0;
			}
			catch
			{
				cvsx = 0;
			}
			try
			{
				cvsy = int.Parse(canvasYSizeTxt.Text);
				if (cvsy < 10) cvsy = 0;
			}
			catch
			{
				cvsy = 0;
			}
			p2i.SetCanvasSize(cvsx, cvsy);

			//画像の論理サイズ
			int x, y;
			try
			{
				x = int.Parse(logSizeXTxt.Text);
				if (x < 10)
				{
					MessageBox.Show("論理画像サイズ x が小さすぎます");
					return;
				}
				if (unitPercentRb.Checked) p2i.SetPictureSize(x, 0, PictureUnit.MLP_PICTURE_UNIT_PERCENT);
				else if (unitInchRb.Checked) p2i.SetPictureSize(x, 0, PictureUnit.MLP_PICTURE_UNIT_INCH);
				else if (unitMmRb.Checked) p2i.SetPictureSize(x, 0, PictureUnit.MLP_PICTURE_UNIT_MM);
				else
				{
					MessageBox.Show("画像サイズの単位を指定してください");
					return;
				}
			}
			catch
			{
				try
				{
					y = int.Parse(logSizeYTxt.Text);
					if (y < 10)
					{
						MessageBox.Show("論理画像サイズ y が小さすぎます");
						return;
					}
					if (unitPercentRb.Checked) p2i.SetPictureSize(0, y, PictureUnit.MLP_PICTURE_UNIT_PERCENT);
					else if (unitInchRb.Checked) p2i.SetPictureSize(0, y, PictureUnit.MLP_PICTURE_UNIT_INCH);
					else if (unitMmRb.Checked) p2i.SetPictureSize(0, y, PictureUnit.MLP_PICTURE_UNIT_MM);
					else
					{
						MessageBox.Show("画像サイズの単位を指定してください");
						return;
					}
				}
				catch
				{
				}
			}

			//透かし(画像)
			if (wtmImgChk.Checked && 0 < wtmImgFileNameTxt.Text.Length)
				p2i.SetImageWatermark(wtmImgFileNameTxt.Text, wtmImgDlg.posX, wtmImgDlg.posY, wtmImgForegroungChk.Checked ? 1 : -1, wtmImgDlg.scaleX, wtmImgDlg.scaleY, wtmImgDlg.alpha);

			//透かし(文字列)
			if (wtmStrChk.Checked && 0 < wtmStrTxt.Text.Length)
			{
				if (wtmStrDlg.fillStr) p2i.SetFillTextWatermark(wtmStrTxt.Text, wtmStrDlg.fontName, wtmStrDlg.posX, wtmStrDlg.posY, wtmStrForegroundChk.Checked ? 1 : -1, wtmStrDlg.fontSize, wtmStrDlg.fontColor, wtmStrDlg.alpha);
				else p2i.SetStrokeTextWatermark(wtmStrTxt.Text, wtmStrDlg.fontName, wtmStrDlg.posX, wtmStrDlg.posY, wtmStrForegroundChk.Checked ? 1 : -1, wtmStrDlg.fontSize, wtmStrDlg.fontColor, wtmStrDlg.alpha);
			}

			//並列処理
			if (splitPageChk.Checked)
			{
				p2i.SetPicture(PictureOpt.THREAD_SPLIT_PAGE, true);
				if (0 < threadDlg.threads) p2i.SetPicture(PictureOpt.THREAD_SPLIT_PAGE_COUNT, threadDlg.threads);
			}
			else
				p2i.SetPicture(PictureOpt.THREAD_SPLIT_PAGE, false);
			if(eachPageChk.Checked)
			{
				p2i.SetPicture(PictureOpt.THREAD_EACH_PAGE, true);
				if (0 < threadDlg.threads) p2i.SetPicture(PictureOpt.THREAD_EACH_PAGE_COUNT, threadDlg.threads);
			}
			else
				p2i.SetPicture(PictureOpt.THREAD_EACH_PAGE, false);

			//出力ファイル
			string outFile = outFileNameTxt.Text;
			if (outFile == "")
			{
				MessageBox.Show("出力ファイルを指定してください");
				return;
			}

			//Buttons
			Cursor.Current = Cursors.WaitCursor;
			exitBtn.Enabled = closeDocBtn.Enabled = pageToPictBtn.Enabled = false;

			//画像変換
			string s = "変換終了";
			if (tiffRb.Checked)
			{
				string page = pageListTxt.Text;
				int res = p2i.CreateTiffMulti(page, outFile);
				if (res <= 0)
				{
					MessageBox.Show("画像変換失敗");
					goto EndProc;
				}
				else
				{
					s = res.ToString() + "ページ画像" + s;
				}
			}
			else
			{
				int page = GetLeadingInteger(pageListTxt.Text);
				if (p2i.CreatePict(page, outFile) != 0)
				{
					MessageBox.Show("画像変換失敗");
					goto EndProc;
				}
			}

			//変換終了
			//MessageBox.Show(s);
			MessageDlg dlg = new MessageDlg(s);
			dlg.imgFile = outFile;
			dlg.ShowDialog();
			dlg = null;
	EndProc:
			Cursor.Current = Cursors.Default;
			exitBtn.Enabled = closeDocBtn.Enabled = pageToPictBtn.Enabled = true;
		}

		/*
		 * アプリケーション終了
		 */
		private void exitBtn_Click(object sender, EventArgs e)
		{
			p2i.CloseDoc();
			p2i.Uninitialize();
			Environment.Exit(0);
		}

		/*
		 * Formが閉じられる
		 */
		private void imager_FormClosing(object sender, FormClosingEventArgs e)
		{
			p2i.CloseDoc();
			p2i.Uninitialize();
		}

		// 画像フォーマット指定
		private void formatRb_CheckedChanged(object sender, EventArgs e)
		{
			if(outFileNameTxt.Text.Length == 0) return;

			string ext = "jpg";
			if (tiffRb.Checked)
			{
				ext = "tiff";
				pageRangeRb.Enabled = pageNumRb.Enabled = allPagesRb.Enabled = true;
				compressNoneRb.Enabled = compressDeflateRb.Enabled = compressLzwRb.Enabled = compressJpgRb.Enabled = true;
			}
			else if (jpegRb.Checked)
			{
				ext = "jpg";
				pageRangeRb.Enabled = pageNumRb.Enabled = allPagesRb.Enabled = false;
				pageNumRb.Enabled = pageNumRb.Checked = true;
				compressNoneRb.Enabled = compressDeflateRb.Enabled = compressLzwRb.Enabled = compressJpgRb.Enabled = false;
			}
			else if (pngRb.Checked)
			{
				ext = "png";
				pageRangeRb.Enabled = pageNumRb.Enabled = false;
				pageNumRb.Enabled = pageNumRb.Checked = true;
				compressNoneRb.Enabled = compressDeflateRb.Enabled = compressLzwRb.Enabled = compressJpgRb.Enabled = false;
			}

			//出力ファイル名
			int pos = outFileNameTxt.Text.LastIndexOf(".") + 1;
			if (pos == 0) outFileNameTxt.Text += "." + ext;
			else outFileNameTxt.Text = outFileNameTxt.Text.Substring(0, pos) + ext;

			//ページ指定
			if (pageNumRb.Checked)
			{
				Match m = (new Regex(@"\d*")).Match(pageListTxt.Text);
				if (m.Value.Length < 0) pageListTxt.Text = "1";
				else pageListTxt.Text = m.Value;
			}
		}

		//ページ範囲・番号指定ラジオボタン
		private void pageRb_Clicked(object sender, EventArgs e)
		{
			if (pageRangeRb.Checked)
			{
				pageRangeLbl.Text = "ページ範囲";
				if (closeDocBtn.Enabled && pageCount > 0)
				{
					int p = GetLeadingInteger(pageListTxt.Text);
					if (p > 0 && p <= pageCount) pageListTxt.Text = p.ToString() + "-" + pageCount.ToString();
					else pageListTxt.Text = "1-" + pageCount.ToString();
				}else
					pageListTxt.Text = "";
			}
			if (pageNumRb.Checked)
			{
				pageRangeLbl.Text ="ページ番号";
				if (closeDocBtn.Enabled && (pageCount > 0))
				{
					int p = GetLeadingInteger(pageListTxt.Text);
					if (p > 0 && p <= pageCount) pageListTxt.Text = p.ToString();
					else pageListTxt.Text = "1";
				}
				else
					pageListTxt.Text = "";
			}
		}

		//ページ指定が変更された
		//このイベントでページの情報を取得し表示を変更する。
		private void pageListTxt_TextChanged(object sender, EventArgs e)
		{
			if (!closeDocBtn.Enabled) return;   /*文書が閉じられている場合はなにもしない*/
			int pgNum = GetLeadingInteger(pageListTxt.Text);
			if (pgNum <= 0) pgNum = 1;
			else if (pageCount < pgNum) pgNum = pageCount;

			//ページ回転
			int rotate;
			p2i.GetPageRotation(pgNum, out rotate);
			pageRotateLbl.Text = "ページ回転: " + rotate;
			pageRotateLbl.Enabled = true;

			//ページサイズ
			PageOrgSize(pgNum);
			PagePictSize(pgNum);

			int x, y;
			p2i.SetPictureResolution(72);
			p2i.GetPicturePixel(pgNum, out x, out y);
		}

		//初期化ファイル
		private void initFileChk_CheckStateChanged(object sender, EventArgs e)
		{
			if (initFileChk.Checked == true) initFileNameTxt.Enabled = initFileRefBtn.Enabled = true;
			else initFileNameTxt.Enabled = initFileRefBtn.Enabled = false;
		}

		//境界の指定が変更
		private void boundsRb_CheckedChanged(object sender, EventArgs e)
		{
			if (mediaBoxRb.Checked) p2i.SetPicture(PictureOpt.PICTURE_USE_MEDIABOX);
			else if(cropBoxRb.Checked) p2i.SetPicture(PictureOpt.PICTURE_USE_CROPBOX);
			else if(bleedBoxRb.Checked) p2i.SetPicture(PictureOpt.PICTURE_USE_BLEEDBOX);
			else if(trimBoxRb.Checked) p2i.SetPicture(PictureOpt.PICTURE_USE_TRIMBOX);
			else if(artBoxRb.Checked) p2i.SetPicture(PictureOpt.PICTURE_USE_ARTBOX);

			//ページ番号
			int pgNum = GetLeadingInteger(pageListTxt.Text);
			if (pgNum <= 0) pgNum = 1;
			else if (pageCount < pgNum) pgNum = pageCount;

			//ページサイズ
			PageOrgSize(pgNum);
			PagePictSize(pgNum);
		}

		//全ページ指定が変更
		private void allPagesRb_CheckedChanged(object sender, EventArgs e)
		{
			pageListTxt.Text = "1-" + pageCount;
		}

		//透かし(画像)
		private void wtmImgChk_CheckedChanged(object sender, EventArgs e)
		{
			if (wtmImgChk.Checked) wtmImgDetailBtn.Enabled = wtmImgForegroungChk.Enabled = wtmImgFileNameTxt.Enabled = wtmImgFileRefBtn.Enabled = true;
			else wtmImgDetailBtn.Enabled = wtmImgForegroungChk.Enabled = wtmImgFileNameTxt.Enabled = wtmImgFileRefBtn.Enabled = false;
		}

		//透かし(画像) 詳細ボタン
		private void wtmImgDetailBtn_Click(object sender, EventArgs e)
		{
			wtmImgDlg.fileName = wtmImgFileNameTxt.Text;
			wtmImgDlg.posZ = wtmImgForegroungChk.Checked;
			if(wtmImgDlg.ShowDialog() != DialogResult.OK) return;
			wtmImgForegroungChk.Checked = wtmImgDlg.posZ;
			wtmImgFileNameTxt.Text = wtmImgDlg.fileName;
		}

		//透かし(文字列)
		private void wtmStrChk_CheckedChanged(object sender, EventArgs e)
		{
			if (wtmStrChk.Checked) wtmStrDetailBtn.Enabled = wtmStrForegroundChk.Enabled = wtmStrTxt.Enabled = true;
			else wtmStrDetailBtn.Enabled = wtmStrForegroundChk.Enabled = wtmStrTxt.Enabled = false;
		}

		//透かし(文字列) 詳細ボタン
		private void wtmStrDetailBtn_Click(object sender, EventArgs e)
		{
			wtmStrDlg.textStr = wtmStrTxt.Text;
			wtmStrDlg.posZ = wtmStrForegroundChk.Checked;
			if (wtmStrDlg.ShowDialog() != DialogResult.OK) return;
			wtmStrForegroundChk.Checked = wtmStrDlg.posZ;
			wtmStrTxt.Text = wtmStrDlg.textStr;
		}

		//カラープロファイル選択
		private void coloprofileBtn_Click(object sender, EventArgs e)
		{
			cprofDlg.ShowDialog();
		}

		//スレッド処理
		private void threadDetailBtn_Click(object sender, EventArgs e)
		{
			threadDlg.split = splitPageChk.Checked;
			threadDlg.each = eachPageChk.Checked;
			if (threadDlg.ShowDialog() != DialogResult.OK) return;
			eachPageChk.Checked = threadDlg.each;
			splitPageChk.Checked = threadDlg.split;
		}

		//フォント情報表示
		private void fontInfoBtn_Click(object sender, EventArgs e)
		{
			PrsFontName[] fontName;
			int len;
			p2i.PrsGetFontInfo(out fontName, out len);
			FontInfoDlg dlg = new FontInfoDlg(fontName);
			dlg.ShowDialog();
		}

		//OCG表示
		private void layerDetailBtn_Click(object sender, EventArgs e)
		{
			if (p2i.GetOcgCount() < 1) return;
			OcgUsage[] usage = p2i.GetOcgUsage();
			LayerDlg dlg = new LayerDlg(usage);
			dlg.ShowDialog();
		}
	}
}
